# coding: utf-8

# flake8: noqa

"""
    Tator REST API

    Interface to the Tator backend.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from tator.api.tator_api import TatorApi
# import ApiClient
from tator.api_client import ApiClient
from tator.configuration import Configuration
# import models into sdk package
from tator.models.algorithm import Algorithm
from tator.models.algorithm_launch import AlgorithmLaunch
from tator.models.algorithm_launch_spec import AlgorithmLaunchSpec
from tator.models.alpha_range import AlphaRange
from tator.models.analysis import Analysis
from tator.models.analysis_spec import AnalysisSpec
from tator.models.attribute_bulk_update import AttributeBulkUpdate
from tator.models.attribute_type import AttributeType
from tator.models.attribute_value import AttributeValue
from tator.models.autocomplete_service import AutocompleteService
from tator.models.bad_request_response import BadRequestResponse
from tator.models.color import Color
from tator.models.color_map import ColorMap
from tator.models.create_list_response import CreateListResponse
from tator.models.create_response import CreateResponse
from tator.models.credentials import Credentials
from tator.models.hex_color import HexColor
from tator.models.image_spec import ImageSpec
from tator.models.leaf import Leaf
from tator.models.leaf_spec import LeafSpec
from tator.models.leaf_suggestion import LeafSuggestion
from tator.models.leaf_type import LeafType
from tator.models.leaf_type_spec import LeafTypeSpec
from tator.models.leaf_type_update import LeafTypeUpdate
from tator.models.leaf_update import LeafUpdate
from tator.models.localization import Localization
from tator.models.localization_spec import LocalizationSpec
from tator.models.localization_type import LocalizationType
from tator.models.localization_type_spec import LocalizationTypeSpec
from tator.models.localization_type_update import LocalizationTypeUpdate
from tator.models.localization_update import LocalizationUpdate
from tator.models.media import Media
from tator.models.media_next import MediaNext
from tator.models.media_prev import MediaPrev
from tator.models.media_sections import MediaSections
from tator.models.media_type import MediaType
from tator.models.media_type_spec import MediaTypeSpec
from tator.models.media_type_update import MediaTypeUpdate
from tator.models.media_update import MediaUpdate
from tator.models.membership import Membership
from tator.models.membership_spec import MembershipSpec
from tator.models.membership_update import MembershipUpdate
from tator.models.message_response import MessageResponse
from tator.models.not_found_response import NotFoundResponse
from tator.models.notify_spec import NotifySpec
from tator.models.one_of_attribute_value import OneOfAttributeValue
from tator.models.one_of_color import OneOfColor
from tator.models.progress_spec import ProgressSpec
from tator.models.progress_summary_spec import ProgressSummarySpec
from tator.models.project import Project
from tator.models.project_spec import ProjectSpec
from tator.models.rgb_color import RgbColor
from tator.models.rgba_color import RgbaColor
from tator.models.section_analysis import SectionAnalysis
from tator.models.state import State
from tator.models.state_spec import StateSpec
from tator.models.state_type import StateType
from tator.models.state_type_spec import StateTypeSpec
from tator.models.state_type_update import StateTypeUpdate
from tator.models.state_update import StateUpdate
from tator.models.temporary_file import TemporaryFile
from tator.models.temporary_file_spec import TemporaryFileSpec
from tator.models.token import Token
from tator.models.transcode import Transcode
from tator.models.transcode_spec import TranscodeSpec
from tator.models.user import User
from tator.models.user_update import UserUpdate
from tator.models.version import Version
from tator.models.version_spec import VersionSpec
from tator.models.version_update import VersionUpdate
from tator.models.video_spec import VideoSpec
from tator.models.video_update import VideoUpdate
